==> gravestones-1.2.1%2B1.21.5%2BA-sources.jar: net/pneumono/gravestones/multiversion/GraveOwner.java <==
package net.pneumono.gravestones.multiversion;

import com.mojang.authlib.GameProfile;
import com.mojang.serialization.Codec;

import java.util.UUID;
import net.minecraft.class_9296;

public class GraveOwner {
    //? if >=1.20.6 {
    public static final Codec<GraveOwner> CODEC = class_9296.field_49359.xmap(GraveOwner::new, GraveOwner::getProfile);
    private class_9296 profile;

    public GraveOwner(class_9296 profile) {
        this.profile = profile;
    }


    public GraveOwner(GameProfile profile) {
        //? if >=1.21.9 {
        /*this(ProfileComponent.ofStatic(profile));
        *///?} else {
        this(new class_9296(profile));
        //?}
    }

    public class_9296 getProfile() {
        return profile;
    }

    public void setProfile(class_9296 profile) {
        this.profile = profile;
    }

    public UUID getUuid() {
        return VersionUtil.getId(VersionUtil.getGameProfile(profile));
    }

    public String getName() {
        return VersionUtil.getName(VersionUtil.getGameProfile(profile));
    }

    //?} else {
    /*public static final Codec<GraveOwner> CODEC = Codecs./^? if >=1.20.2 {^/GAME_PROFILE_WITH_PROPERTIES/^?} else {^//^GAME_PROFILE^//^?}^/.xmap(GraveOwner::new, GraveOwner::getProfile);
    private GameProfile profile;

    public GraveOwner(GameProfile profile) {
        this.profile = profile;
    }

    public GameProfile getProfile() {
        return this.profile;
    }

    public void setProfile(GameProfile profile) {
        this.profile = profile;
    }

    public UUID getUuid() {
        return VersionUtil.getId(this.profile);
    }

    public String getName() {
        return VersionUtil.getName(this.profile);
    }
    *///?}

    public String getNotNullName() {
        String name = getName();
        return name == null ? "???" : name;
    }
}

==> gravestones-1.2.2%2B1.21.9%2BA-sources.jar: net/pneumono/gravestones/multiversion/GraveOwner.java <==
package net.pneumono.gravestones.multiversion;

import com.mojang.authlib.GameProfile;
import com.mojang.serialization.Codec;

import java.util.UUID;
import net.minecraft.class_9296;

public class GraveOwner {
    //? if >=1.20.6 {
    public static final Codec<GraveOwner> CODEC = class_9296.field_49359.xmap(GraveOwner::new, GraveOwner::getProfile);
    private class_9296 profile;

    public GraveOwner(class_9296 profile) {
        this.profile = profile;
    }


    public GraveOwner(GameProfile profile) {
        //? if >=1.21.9 {
        this(class_9296.method_73307(profile));
        //?} else {
        /*this(new ProfileComponent(profile));
        *///?}
    }

    public class_9296 getProfile() {
        return profile;
    }

    public void setProfile(class_9296 profile) {
        this.profile = profile;
    }

    public UUID getUuid() {
        return VersionUtil.getId(VersionUtil.getGameProfile(profile));
    }

    public String getName() {
        return VersionUtil.getName(VersionUtil.getGameProfile(profile));
    }

    //?} else {
    /*public static final Codec<GraveOwner> CODEC = Codecs./^? if >=1.20.2 {^/GAME_PROFILE_WITH_PROPERTIES/^?} else {^//^GAME_PROFILE^//^?}^/.xmap(GraveOwner::new, GraveOwner::getProfile);
    private GameProfile profile;

    public GraveOwner(GameProfile profile) {
        this.profile = profile;
    }

    public GameProfile getProfile() {
        return this.profile;
    }

    public void setProfile(GameProfile profile) {
        this.profile = profile;
    }

    public UUID getUuid() {
        return VersionUtil.getId(this.profile);
    }

    public String getName() {
        return VersionUtil.getName(this.profile);
    }
    *///?}

    public String getNotNullName() {
        String name = getName();
        return name == null ? "???" : name;
    }
}
